from django.shortcuts import render, redirect
from applipizza.models import Pizza, Ingredient, Composition
from applipizza.forms import IngredientForm, CompositionForm, PizzaForm

# Create your views here.
def pizzas(request):
    pizzas = Pizza.objects.all()
    return render(
        request,
        'applipizza/pizzas.html',
        {'pizzas': pizzas}
    )


def pizza(request, id):
    return viewPizza(request, id)

def formulaireCreationIngredient(request):
    formulaire = IngredientForm()

    return render(
        request,
        'applipizza/formulaireCreationIngredient.html',
        {"form": formulaire}
    )

def creerIngredient(request):
    form = IngredientForm(request.POST)
    if form.is_valid():
        nomIngredient = form.cleaned_data['nom']
        ingredient = Ingredient(nom=nomIngredient)
        ingredient.save()

        formulaire = IngredientForm()

        return render(
            request,
            'applipizza/formulaireCreationIngredient.html',
            {"form": IngredientForm(), "status": "success", "nomIngredient": nomIngredient}
        )
    else:
        return render(
            request,
            'applipizza/formulaireCreationIngredient.html',
            {"form": form, "status": "error"}
        )

def ajouterIngredientDansPizza(request, id):
    pizza = Pizza.objects.get(id=id)
    composition = Composition.objects.filter(pizza_id=id)
    compositionArray = []
    for c in composition:
        compositionArray.append([Ingredient.objects.get(id=c.ingredient_id).nom, c.quantite])
    pizza.composition = compositionArray

    form = CompositionForm(request.POST)
    if form.is_valid():
        ingredient = form.cleaned_data['ingredient']
        quantite = form.cleaned_data['quantite']
        composition = Composition(ingredient=ingredient, quantite=quantite, pizza=pizza)
        composition.save()

        return viewPizza(request, id, 'success')

def supprimerPizza(request, id):
    pizza = Pizza.objects.get(id=id)

    pizza.delete()
    composition = Composition.objects.filter(pizza_id=id)
    composition.delete()
    pizzas = Pizza.objects.all()
    return render(
        request,
        'applipizza/pizzas.html',
        {'pizzas': pizzas}
    )

def modifierPizza(request, id):
    pizza = Pizza.objects.get(id=id)
    formulaire = PizzaForm(instance = pizza)
    return render(
        request,
        'applipizza/formulaireModificationPizza.html',
        {'pizza': pizza, 'form': formulaire}
    )

def traitementFormulaireModificationPizza(request, id):
    pizza = Pizza.objects.get(id=id)
    form = PizzaForm(request.POST, request.FILES)

    if form.is_valid():
        pizza.nom = form.cleaned_data['nom']
        pizza.prix = form.cleaned_data['prix']
        pizza.image = request.FILES['image']
        pizza.save()

        return viewPizza(request, id, 'success')
    else:
        return viewPizza(request, id, 'error')

def viewPizza(request, id, status=None):
    formulaire = CompositionForm()

    pizza = Pizza.objects.get(id=id)
    composition = Composition.objects.filter(pizza_id=id)
    compositionArray = []
    for c in composition:
        compositionArray.append([c.id, Ingredient.objects.get(id=c.ingredient_id).nom, c.quantite])
    pizza.composition = compositionArray

    if status==None:
        return render(
            request,
            'applipizza/pizza.html',
            {"pizza": pizza, 'form': formulaire}
        )
    else:
        return render(
            request,
            'applipizza/pizza.html',
            {"pizza": pizza, 'form': formulaire, 'status': status}
        )

def supprimerIngredientDansPizza(request, pizzaId, compositionId):
    composition = Composition.objects.get(id=compositionId)
    composition.delete()
    return viewPizza(request, pizzaId, 'success')

def create_pizza(request):
    if request.method == 'POST':
        form = PizzaForm(request.POST, request.FILES)
        if form.is_valid():
            form.save()
            return redirect('home')
        print(form.errors)
    else:
        form = PizzaForm()
    return render(
        request,
        'applipizza/formulaireCreationPizza.html',
        {'form': form}
    )

def listeIngredients(request):
    ingredients = Ingredient.objects.all()
    return render(
        request,
        'applipizza/ingredients.html',
        {'ingredients': ingredients}
    )